#
# spec file for package age
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021-2024, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           age
Version:        1.2.1
Release:        1.3
Summary:        A file encryption tool
License:        BSD-3-Clause
Group:          Productivity/Networking/Security
URL:            https://github.com/FiloSottile/age
#Git-Clone:     https://github.com/FiloSottile/age.git
Source:         https://github.com/FiloSottile/age/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go
BuildRequires:  golang-packaging
%{go_provides}

%description
Age features small explicit keys, no config options, and UNIX-style
composability.

%prep
%autosetup -p 1 -a 1

%build
%{goprep} filippo.io/age
%{gobuild} -mod=vendor ...

%install
%{goinstall}
for i in age.1 age-keygen.1 ; do
  install -Dm 0644 doc/$i %{buildroot}%{_mandir}/man1/$i
done

%check
# disable test for now since it needs dependencies that are not vendored yet
#%%gotest filippo.io/age ...

%files
%license LICENSE
%doc README.md doc/*.1.html
%{_bindir}/age
%{_bindir}/age-keygen
%{_mandir}/man1/age-keygen.1%{?ext_man}
%{_mandir}/man1/age.1%{?ext_man}

%changelog
* Wed Dec 18 2024 Martin Hauke <mardnh@gmx.de>
- Update to version 1.2.1
  * This release fixes a security vulnerability that could allow
    an attacker to execute an arbitrary binary under certain
    conditions.
    See: https://github.com/FiloSottile/age/security/advisories/GHSA-32gq-x56h-299c
  * Plugin names may now only contain alphanumeric characters or
    the four special characters +-._.
* Tue Jul  2 2024 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 1.2.0
  * A small release to build the release binaries with a more
    recent Go toolchain, and to fix a couple CLI edge cases.
  * The Go module now exposes a plugin package that provides an age
    plugin client. That is, Recipient and Identity implementations
    that invoke a plugin binary, allowing the use of age plugins
    in Go programs.
  * Finally, Recipients can now return a set of "labels"
    by implementing RecipientWithLabels. This allows replicating
    the special behavior of the scrypt Recipient in third-party
    Recipients, or applying policy useful for authenticated
    or post-quantum Recipients.
* Mon Dec 26 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 1.1.1
  Plugins support
  * The age CLI now supports plugins, such as age-plugin-yubikey
  Breaking changes
  * If -i is used, passphrase-encrypted files are now rejected.
  * Empty final chunks are now rejected.
  Minor changes
  * PKCS#8-encoded Ed25519 private keys (such as 1Password exports)
    are now supported as SSH identities.
  * If an armored file is pasted into the terminal, age will now
    attempt to wait until the end of the file before prompting for
    a password.
  * Some invalid files are now correctly rejected, in particular
    encrypted files with trailing data.
  * If /dev/tty is present but can't be opened, age will now
    fallback to trying to treat stdin as a terminal as if
    /dev/tty wasn't present.
  * Input prompts now go to the terminal, even if standard error#
    is redirected.
  * Values of the new armor.Error type are now returned wrapped in
    decryption errors when appropriate.
  * Documentation and error messages were improved.
* Sat Oct 16 2021 Jan Engelhardt <jengelh@inai.de>
- Remove filler phrases from descriptions.
* Tue Sep  7 2021 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.0.0
